package somcolorapp;

/**
 * Package somcolorapp
 * Classification des couleurs avec un rseau de Kohonen.
 * Rseaux Neauronaux, Vuibert 2006.
 * Jean-Philippe Rennard
 * version 1.0, 17/3/2006
 */

import java.awt.*;
import baseui.*;

import neuronespack.*;

/**
 * <p>Title: Processus Nim</p>
 * <p>Description: Gestion du processus.</p>
 */
public class SOMColorProcess extends Cprocess {

  /** Pointeur sur l'interface utilisateur */
  SOMColorUI appUI;
  /** Vue */
  SOMColorVue somVue;
  /** Reseau de calcul */
  ReseauSOMColor leReseau;
  /** Dimension de la carte (ct) */
  int tailleCarte;

  /**
   * Constructeur du processus dans une interface utilisateur.
   * @param ui SOMColorUI : interface utilisateur
   */
  public SOMColorProcess(SOMColorUI ui) {
    super(ui);
    appUI = ui;
    somVue = new SOMColorVue(this, Color.white, Color.black);
    vue = (Cvue)somVue;
    tempoProcess = 1;
  }

  /** Initialisation du rseau  */
  public void initReseau() {
    tailleCarte = appUI.tailleReseau;
    generation = 0;
    leReseau = new ReseauSOMColor(this, appUI.tailleReseau, appUI.maxIterations,
                                  appUI.nbCouleurs, appUI.eta0, appUI.sigma0);
  }

  /** Rinitialisation du rseau */
  public void reInit() {
    initReseau();
    initVue();
  }

  /** Itration suivante */
  public void geneSuiv() {
    if(generation>leReseau.getMaxIteration()) {
      appUI.stopGo();
      return;
    }
    leReseau.epoque();
    somVue.afficheCarte();
      somVue.repaint();
    appUI.affGeneration();
    generation++;
  }

  /** Initialisation/MAJ de la vue */
  public void initVue() {
    somVue.setNewSize();
    somVue.afficheCarte();
  }

}
